@@ -1,8 +1,23 @@
 from django.core.cache import cache
+from django.http import HttpResponseRedirect
+from django.core.urlresolvers import reverse
 from omblog import settings as o_settings
 from omblog.cache import get_key
 
 
+def login_required(fn):
+    """will redirect to the admin login page if a user 
+    is not authed"""
+    def _login_required(request, *args, **kwargs):
+        if not request.user.is_authenticated():
+            url = '%s?next=%s' % (
+                reverse('omblog:login'),
+                request.META.get('PATH_INFO')
+            )
+            return HttpResponseRedirect(url)
+        return fn(request, *args, **kwargs)
+    return _login_required
+
 def cache_page(fn):
     """If a cached version of the page exists - return that
     unless the kill clearcache parameter is in the get and
