@@ -9,6 +9,10 @@ RSS_TITLE = getattr(django_settings,
 RSS_LINK = getattr(django_settings,
                             'OMBLOG_RSS_LINK',
                             '/blog/')
+"""cache timeout"""
+CACHE_TIMEOUT = getattr(django_settings,
+                            'OMBLOG_CACHE_TIMEOUT',
+                           60)
 """Cache Enabled?"""
 CACHE_ENABLED = getattr(django_settings,
                             'OMBLOG_CACHE_ENABLED',
