@@ -6,6 +6,13 @@ urlpatterns = patterns('',
     url(r'^feed\.rss$',
         PostFeed(),
         name='feed'),
+    url(r'^login/$',
+        'django.contrib.auth.views.login',
+        {'template_name': 'omblog/login.html'},
+        name='login'),
+    url(r'^edit/(?P<pk>\d+)/$',
+        'omblog.views.edit',
+        name='edit'),
     url(r'^tags/(?P<slug>[\w\-]+)/$',
         'omblog.views.tag',
         name='tag'),
